@@ -2,11 +2,14 @@ import boto3
 import pickle
 import subprocess
 from io import BytesIO
+from trell_ai_util.aws import cred
 
 
 def read_from_s3_bucket(bucket='data-science-datas', sub_bucket='tests/', file_name='test.pkl'):
     key = sub_bucket + file_name
-    s3 = boto3.resource('s3')
+    s3 = boto3.resource('s3', aws_access_key_id=cred['ACCESS_KEY'],
+                              aws_secret_access_key=cred['SECRET_KEY'])
+
     print("Reading data from : " + bucket + "/" + key)
     with BytesIO() as data:
         s3.Bucket(bucket).download_fileobj(key, data)
@@ -19,7 +22,8 @@ def write_to_s3_bucket(python_data_object=None, bucket='data-science-datas', sub
     key = sub_bucket + file_name
     pickle_byte_obj = pickle.dumps(python_data_object)
     print("Writing data to : " + bucket + "/" + key)
-    s3_resource = boto3.resource('s3')
+    s3_resource = boto3.resource('s3', aws_access_key_id=cred['ACCESS_KEY'],
+                              aws_secret_access_key=cred['SECRET_KEY'])
     s3_resource.Object(bucket, key).put(Body=pickle_byte_obj)
 
 
