@@ -17,7 +17,7 @@ try:
         )
         response = client.get_secret_value(SecretId=secret_name)
         cred = json.loads(response['SecretString'])
-        logging.info("----------- Connected to AWS via AWS CLI configured credentials -----------------------")
+        print("----------- Connected to AWS via IAM role or AWS CLI configured credentials -----------------------")
     except Exception as err:
         client = session.client(
             service_name='secretsmanager',
@@ -27,9 +27,9 @@ try:
         )
         response = client.get_secret_value(SecretId=secret_name)
         cred = json.loads(response['SecretString'])
-        logging.info("----------- Connected to AWS via environment credentials -----------------------")
+        print("----------- Connected to AWS via environment credentials -----------------------")
 
     
 except Exception as err:
-    logging.error("* you are not authorized to use Trell pip package *")
-    logging.info("** Either setup AWS CLI or place trell.env in the current folder **")
+    print("* you are not authorized to use Trell pip package *")
+    print("** Either setup AWS CLI or place trell.env in the working directory **")
